==> haskell-th-orphans-0.13.16-62.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-orphans
version:              0.13.16
visibility:           public
id:                   th-orphans-0.13.16-x2p4Pj1aYA6bkrdDunvhC
key:                  th-orphans-0.13.16-x2p4Pj1aYA6bkrdDunvhC
license:              BSD-3-Clause
copyright:            (c) Matt Morrow, Michael Sloan, Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Matt Morrow, Michael Sloan, Ryan Scott
stability:            experimental
synopsis:             Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.

category:             Template Haskell
abi:                  0eaec1e282da4db1a141f156c7345528
exposed:              True
exposed-modules:      Language.Haskell.TH.Instances
hidden-modules:       Language.Haskell.TH.Instances.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/th-orphans-0.13.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/th-orphans-0.13.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/th-orphans-0.13.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-orphans
hs-libraries:         HSth-orphans-0.13.16-x2p4Pj1aYA6bkrdDunvhC
depends:
    base-4.18.2.1 mtl-2.3.1 template-haskell-2.20.0.0
    th-compat-0.1.6-GpjIKGc0GPMFBEveh1mM8h
    th-lift-0.8.6-IRGSsrKtWq3BZSHvMwfeE6
    th-reify-many-0.1.10-AFncENUC9O8AvMG0k1A0n3

haddock-interfaces:   /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html:         /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-orphans-0.13.16-63-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-orphans
version:              0.13.16
visibility:           public
id:                   th-orphans-0.13.16-7vRRXCTUh27LcIJ3KgMdVn
key:                  th-orphans-0.13.16-7vRRXCTUh27LcIJ3KgMdVn
license:              BSD-3-Clause
copyright:            (c) Matt Morrow, Michael Sloan, Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Matt Morrow, Michael Sloan, Ryan Scott
stability:            experimental
synopsis:             Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.

category:             Template Haskell
abi:                  cdf7ea2a5270742afab3271fb8b6ad56
exposed:              True
exposed-modules:      Language.Haskell.TH.Instances
hidden-modules:       Language.Haskell.TH.Instances.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/th-orphans-0.13.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/th-orphans-0.13.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/th-orphans-0.13.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-orphans
hs-libraries:         HSth-orphans-0.13.16-7vRRXCTUh27LcIJ3KgMdVn
depends:
    base-4.18.2.1 mtl-2.3.1 template-haskell-2.20.0.0
    th-compat-0.1.6-KectvLb9yylAlpm8iQXOj
    th-lift-0.8.6-IRGSsrKtWq3BZSHvMwfeE6
    th-reify-many-0.1.10-3aSXEZO0WLV6vSakOufT0x

haddock-interfaces:   /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html:         /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
